@@ -84,17 +84,8 @@ var gABI        = null;
 var gConsole    = null;
 var gLogEnabled = { };
 
-/**
- * Logs a string to the error console. 
- * @param   string
- *          The string to write to the error console..
- */  
-function LOG(module, string) {
-  if (module in gLogEnabled) {
-    dump("*** " + module + ":" + string + "\n");
-    gConsole.logStringMessage(string);
-  }
-}
+// shared code for suppressing bad cert dialogs
+//@line 40 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/../../shared/src/badCertHandler.js"
 
 /**
  * Only allow built-in certs for HTTPS connections.  See bug 340198.
@@ -118,6 +109,75 @@ function checkCert(channel) {
     throw "cert issuer is not built-in";
 }
 
+/**
+ * This class implements nsIBadCertListener.  It's job is to prevent "bad cert"
+ * security dialogs from being shown to the user.  It is better to simply fail
+ * if the certificate is bad. See bug 304286.
+ */
+function BadCertHandler() {
+}
+BadCertHandler.prototype = {
+
+  // nsIBadCertListener
+  confirmUnknownIssuer: function(socketInfo, cert, certAddType) {
+    LOG("EM BadCertHandler: Unknown issuer");
+    return false;
+  },
+
+  confirmMismatchDomain: function(socketInfo, targetURL, cert) {
+    LOG("EM BadCertHandler: Mismatched domain");
+    return false;
+  },
+
+  confirmCertExpired: function(socketInfo, cert) {
+    LOG("EM BadCertHandler: Expired certificate");
+    return false;
+  },
+
+  notifyCrlNextupdate: function(socketInfo, targetURL, cert) {
+  },
+
+  // nsIChannelEventSink
+  onChannelRedirect: function(oldChannel, newChannel, flags) {
+    // make sure the certificate of the old channel checks out before we follow
+    // a redirect from it.  See bug 340198.
+    checkCert(oldChannel);
+  },
+
+  // nsIInterfaceRequestor
+  getInterface: function(iid) {
+    if (iid.equals(Components.interfaces.nsIBadCertListener) ||
+        iid.equals(Components.interfaces.nsIChannelEventSink))
+      return this;
+
+    Components.returnCode = Components.results.NS_ERROR_NO_INTERFACE;
+    return null;
+  },
+
+  // nsISupports
+  QueryInterface: function(iid) {
+    if (!iid.equals(Components.interfaces.nsIBadCertListener) &&
+        !iid.equals(Components.interfaces.nsIChannelEventSink) &&
+        !iid.equals(Components.interfaces.nsIInterfaceRequestor) &&
+        !iid.equals(Components.interfaces.nsISupports))
+      throw Components.results.NS_ERROR_NO_INTERFACE;
+    return this;
+  }
+};
+//@line 128 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
+
+/**
+ * Logs a string to the error console. 
+ * @param   string
+ *          The string to write to the error console..
+ */  
+function LOG(module, string) {
+  if (module in gLogEnabled) {
+    dump("*** " + module + ":" + string + "\n");
+    gConsole.logStringMessage(string);
+  }
+}
+
 /**
  * Convert a string containing binary values to hex.
  */
@@ -493,6 +553,21 @@ function readStringFromFile(file) {
   return text;
 }
 
+// Read the update channel from defaults only.  We do this to ensure that
+// the channel is tightly coupled with the application and does not apply
+// to other instances of the application that may use the same profile.
+function getUpdateChannel() {
+  try {
+    var defaults =
+        gPref.QueryInterface(Components.interfaces.nsIPrefService).
+        getDefaultBranch(null);
+
+    return defaults.getCharPref(PREF_APP_UPDATE_CHANNEL);
+  } catch (e) {
+    return "default";  // failover when pref not found
+  }
+}
+
 /**
  * Update Patch
  * @param   patch
@@ -753,6 +828,9 @@ Update.prototype = {
     update.setAttribute("detailsURL", this.detailsURL);
     update.setAttribute("licenseURL", this.licenseURL);
     update.setAttribute("serviceURL", this.serviceURL);
+    // to properly support updates to the MOZILLA_1_8_BRANCH and trunk
+    // write out the channel.  see bug #368082 for more details
+    update.setAttribute("channel", getUpdateChannel());
     update.setAttribute("installDate", this.installDate);
     update.setAttribute("statusText", this.statusText);
     update.setAttribute("buildID", this.buildID);
@@ -849,7 +927,7 @@ function UpdateService() {
     LOG("UpdateService", "XPCOM ABI unknown: updates are not possible.");
   }
 
-//@line 900 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
+//@line 899 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
 
   // Start the update timer only after a profile has been selected so that the
   // appropriate values for the update check are read from the user's profile.  
@@ -1640,65 +1718,6 @@ UpdateManager.prototype = {
   }
 };
 
-/**
- * This class implements nsIBadCertListener.  It's job is to prevent "bad cert"
- * security dialogs from being shown to the user.  It is better to simply fail
- * if the certificate is bad.  See bug 304286.
- */
-function BadCertHandler() {
-}
-BadCertHandler.prototype = {
-  /**
-   * See nsIBadCertListener
-   */
-  confirmUnknownIssuer: function(socketInfo, cert, certAddType) {
-    return false;
-  },
-
-  confirmMismatchDomain: function(socketInfo, targetURL, cert) {
-    return false;
-  },
-
-  confirmCertExpired: function(socketInfo, cert) {
-    return false;
-  },
-
-  notifyCrlNextupdate: function(socketInfo, targetURL, cert) {
-  },
-
-  /**
-   * See nsIChannelEventSink
-   */
-  onChannelRedirect: function(oldChannel, newChannel, flags) {
-    // make sure the certificate of the old channel checks out before we follow
-    // a redirect from it.  See bug 340198.
-    checkCert(oldChannel);
-  },
-
-  /**
-   * See nsIInterfaceRequestor
-   */
-  getInterface: function(iid) {
-    if (iid.equals(Components.interfaces.nsIBadCertListener) ||
-        iid.equals(Components.interfaces.nsIChannelEventSink))
-      return this;
-
-    Components.returnCode = Components.results.NS_ERROR_NO_INTERFACE;
-    return null;
-  },
-
-  /**
-   * See nsISupports
-   */
-  QueryInterface: function(iid) {
-    if (!iid.equals(Components.interfaces.nsIBadCertListener) &&
-        !iid.equals(Components.interfaces.nsIChannelEventSink) &&
-        !iid.equals(Components.interfaces.nsIInterfaceRequestor) &&
-        !iid.equals(Components.interfaces.nsISupports))
-      throw Components.results.NS_ERROR_NO_INTERFACE;
-    return this;
-  }
-};
 
 /**
  * Checker
@@ -1743,17 +1762,6 @@ Checker.prototype = {
       return null;
     }
 
-    // Read the update channel from defaults only.  We do this to ensure that
-    // the channel is tightly coupled with the application and does not apply
-    // to other instances of the application that may use the same profile.
-    function getUpdateChannel() {
-      try {
-        return defaults.getCharPref(PREF_APP_UPDATE_CHANNEL);
-      } catch (e) {
-        return "default";  // failover when pref not found
-      }
-    }
-
     url = url.replace(/%PRODUCT%/g, gApp.name);
     url = url.replace(/%VERSION%/g, gApp.version);
     url = url.replace(/%BUILD_ID%/g, gApp.appBuildID);
@@ -2545,7 +2553,7 @@ TimerManager.prototype = {
   }
 };
 
-//@line 2596 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
+//@line 2525 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
 /**
  * UpdatePrompt
  * An object which can prompt the user with information about updates, request
@@ -2687,7 +2695,7 @@ UpdatePrompt.prototype = {
     return this;
   }
 };
-//@line 2738 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
+//@line 2667 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
 
 var gModule = {
   registerSelf: function(componentManager, fileSpec, location, type) {
@@ -2739,13 +2747,13 @@ var gModule = {
                className  : "Update Checker",
                factory    : #1#(Checker)
              },
-//@line 2790 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
+//@line 2719 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
     prompt:  { CID        : Components.ID("{27ABA825-35B5-4018-9FDD-F99250A0E722}"),
                contractID : "@mozilla.org/updates/update-prompt;1",
                className  : "Update Prompt",
                factory    : #1#(UpdatePrompt)
              },
-//@line 2796 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
+//@line 2725 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
     timers:  { CID        : Components.ID("{B322A5C0-A419-484E-96BA-D7182163899F}"),
                contractID : "@mozilla.org/updates/timer-manager;1",
                className  : "Timer Manager",
@@ -2776,14 +2784,14 @@ function NSGetModule(compMgr, fileSpec) {
  *          the specified update, false otherwise.
  */
 function isCompatible(update) {
-//@line 2827 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
+//@line 2756 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
   var em = 
       Components.classes["@mozilla.org/extensions/manager;1"].
       getService(Components.interfaces.nsIExtensionManager);
   var items = em.getIncompatibleItemList("", update.extensionVersion,
     nsIUpdateItem.TYPE_ADDON, false, { });
   return items.length == 0;
-//@line 2836 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
+//@line 2765 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
 }
 
 /**
@@ -2802,7 +2810,7 @@ function showPromptIfNoIncompatibilities(update) {
     prompter.showUpdateAvailable(update);
   }
 
-//@line 2855 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
+//@line 2784 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
   /**
    * Determines if an addon is compatible with a particular update.
    * @param   addon
@@ -2902,6 +2910,6 @@ function showPromptIfNoIncompatibilities(update) {
     em.update([], 0, mode != 0, listener);
   }
   else
-//@line 2955 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
+//@line 2884 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
     showPrompt(update);
 }
