@@ -9,21 +9,21 @@ package org.mozilla.xpcom;
 
 public interface nsIDOMCSSValue extends nsISupports
 {
-  String NS_IDOMCSSVALUE_IID =
+  public static final String NS_IDOMCSSVALUE_IID =
     "{009f7ea5-9e80-41be-b008-db62f10823f2}";
 
-  int CSS_INHERIT = 0;
+  public static final int CSS_INHERIT = 0;
 
-  int CSS_PRIMITIVE_VALUE = 1;
+  public static final int CSS_PRIMITIVE_VALUE = 1;
 
-  int CSS_VALUE_LIST = 2;
+  public static final int CSS_VALUE_LIST = 2;
 
-  int CSS_CUSTOM = 3;
+  public static final int CSS_CUSTOM = 3;
 
-  String getCssText();
+  public String getCssText();
 
-  void setCssText(String arg1);
+  public void setCssText(String arg1);
 
-  int getCssValueType();
+  public int getCssValueType();
 
 }
