@@ -9,9 +9,9 @@ package org.mozilla.xpcom;
 
 public interface nsIInterfaceRequestor extends nsISupports
 {
-  String NS_IINTERFACEREQUESTOR_IID =
+  public static final String NS_IINTERFACEREQUESTOR_IID =
     "{033a1470-8b2a-11d3-af88-00a024ffc08c}";
 
-  nsISupports getInterface(String arg1);
+  public nsISupports getInterface(String arg1);
 
 }
