@@ -9,9 +9,9 @@ package org.mozilla.xpcom;
 
 public interface nsIRegistryEnumerator extends nsIEnumerator
 {
-  String NS_IREGISTRYENUMERATOR_IID =
+  public static final String NS_IREGISTRYENUMERATOR_IID =
     "{8cecf236-1dd2-11b2-893c-f9848956eaec}";
 
-  String currentItemInPlaceUTF8(long[] arg1);
+  public String currentItemInPlaceUTF8(long[] arg1);
 
 }
